NLSL: File Members

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

- All
- Functions/Subroutines
- Variables
- Typedefs
- Macros

- a
- b
- c
- d
- e
- f
- g
- h
- i
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w
- x
- z

Here is a list of all file members with links to the files they belong to:

### - o -

- offset : genio.c
- OK : genio.c
- ordrpr() : ordrpr.f90
- outputfile : genio.c